## Installation

1. First, install GDAL manually:

   - On Windows:
     ```
     pip install gdal
     ```
   - If you have Python 3.9 or lower, install from:
     [Unofficial GDAL Wheels](https://www.lfd.uci.edu/~gohlke/pythonlibs/#gdal)

2. Then install rasmas: